commit

Function commit 

pub fn commit<M, RNG>(
    secret: &SigningShare<M>,
    rng: &mut RNG,
) -> (SigningNonces<M>, SigningCommitments<M>)
Performed once by each participant selected for the signing operation.

Generates the signing nonces and commitments to be used in the signing operation.