SigningCommitments

Type Alias SigningCommitments 

pub type SigningCommitments<M> = SigningCommitments<BluePallas<M>>;
Published by each participant in the first round of the signing protocol.

This step can be batched if desired by the implementation. Each SigningCommitment can be used for exactly one signature.

Aliased Type

pub struct SigningCommitments<M> { /* private fields */ }